@@ -9,7 +9,11 @@ class Printer:
         self.__init__(tag)
 
     def error(self, text: str, tag: str = None) -> None:
-        print_color(text, tag=self.tag if tag is None else tag, tag_color='red', color='white')
+        print_color(
+            text, tag=self.tag if tag is None else tag, tag_color="red", color="white"
+        )
 
     def info(self, text: str, tag: str = None) -> None:
-        print_color(text, tag=self.tag if tag is None else tag, tag_color='green', color='white')
+        print_color(
+            text, tag=self.tag if tag is None else tag, tag_color="green", color="white"
+        )
